pub fn x11_set_sm_client_id(sm_client_id: Option<&str>)👎Deprecated:
Since 4.18
s state using the X11R6 ICCCM session management protocol.
See the X Session Management Library documentation for more information on session management and the Inter-Client Communication Conventions Manual
Deprecated since 4.18
sm_client_id
the client id assigned by the session manager
when the connection was opened, or None to remove the property.